@@ -195,22 +195,27 @@ class Window(Gtk.ApplicationWindow):
         self._box.pack_start(self.player.actionbar, False, False, 0)
         self._box.pack_start(self.selection_toolbar.actionbar, False, False, 0)
         self.add(self._box)
-        count = 1
+        count = 0
         cursor = None
-        try:
-            cursor = tracker.query(Query.all_songs_count(), None)
-        except Exception as e:
-            logger.error("Tracker query crashed: %s" % e)
-            count = 0
 
-        if cursor is not None and cursor.next(None):
-            count = cursor.get_integer(0)
-        if count > 0:
-            self._switch_to_player_view()
-        # To revert to the No Music View when no songs are found
+        if Query.music_folder and Query.download_folder:
+            try:
+                cursor = tracker.query(Query.all_songs_count(), None)
+                if cursor is not None and cursor.next(None):
+                    count = cursor.get_integer(0)
+            except Exception as e:
+                logger.error("Tracker query crashed: %s" % e)
+                count = 0
+
+            if count > 0:
+                self._switch_to_player_view()
+            # To revert to the No Music View when no songs are found
+            else:
+                if self.toolbar._selectionMode is False:
+                    self._switch_to_empty_view()
         else:
-            if self.toolbar._selectionMode is False:
-                self._switch_to_empty_view()
+            # Revert to No Music view if XDG dirs are not set
+            self._switch_to_empty_view()
 
         self.toolbar._search_button.connect('toggled', self._on_search_toggled)
         self.toolbar.connect('selection-mode-changed', self._on_selection_mode_changed)
@@ -359,7 +364,8 @@ class Window(Gtk.ApplicationWindow):
 
     @log
     def _on_search_toggled(self, button, data=None):
-        self.toolbar.searchbar.show_bar(button.get_active())
+        self.toolbar.searchbar.show_bar(button.get_active(),
+                                        self.curr_view != self.views[4])
         if not button.get_active() and self.curr_view == self.views[4] and \
            self.toolbar._state == ToolbarState.MAIN:
             self._stack.set_visible_child(self.prev_view)
